<?php

if ( ! current_user_can( get_option( $this->shared->get( 'slug' ) . '_capability_menu_categories' ) ) ) {
	wp_die( esc_html__( 'You do not have sufficient permissions to access this page.', 'lightweight-cookie-notice') );
}

?>

<!-- process data -->

<?php

if ( isset( $_POST['form_submitted'] ) ) {

	//Sanitization -----------------------------------------------------------------------------------------------------
	$update_id      = isset( $_POST['update_id'] ) ? intval( $_POST['update_id'] ) : '';
	$name           = sanitize_text_field( $_POST['name'] );
	$description    = $this->shared->apply_custom_kses( $_POST['description'] );
	$toggle         = intval( $_POST['toggle'], 10 );
	$default_status = intval( $_POST['default_status'], 10 );
	$priority       = intval( $_POST['priority'], 10 );
	$script_head    = $_POST['script_head'];
	$script_body    = $_POST['script_body'];
	$script_accept_cookies    = $_POST['script_accept_cookies'];
	$section_id     = intval( $_POST['section_id'], 10 );

	//Validation -------------------------------------------------------------------------------------------------------

	$invalid_data_message = '';

	//validation on "name"
	if ( mb_strlen( trim( $name ) ) === 0 or mb_strlen( trim( $name ) ) > 100 ) {
		$invalid_data_message .= '<div class="error settings-error notice is-dismissible below-h2"><p>' . esc_html__( 'Please enter a valid value in the "Name" field.', 'lightweight-cookie-notice') . '</p></div>';
		$invalid_data         = true;
	}

	//validation on "description"
	if ( mb_strlen( trim( $description ) ) === 0 or mb_strlen( trim( $description ) ) > 100000 ) {
		$invalid_data_message .= '<div class="error settings-error notice is-dismissible below-h2"><p>' . esc_html__( 'Please enter a valid value in the "Description" field.', 'lightweight-cookie-notice') . '</p></div>';
		$invalid_data         = true;
	}

}

//Update or add the record in the database
if ( isset( $_POST['form_submitted'] ) and ! isset( $invalid_data ) ) {

	if ( isset( $update_id ) and ! empty( $update_id ) ) {

		//Update

		global $wpdb;
		$table_name = $wpdb->prefix . $this->shared->get( 'slug' ) . "_category";
		$safe_sql   = $wpdb->prepare( "UPDATE $table_name SET 
                name = %s,
                description = %s,
                toggle = %d,
                default_status = %d,
                priority = %d,
                script_head = %s,
                script_body = %s,
                script_accept_cookies = %s,
                section_id = %d
                WHERE category_id = %d",
			$name,
			$description,
			$toggle,
			$default_status,
			$priority,
			$script_head,
			$script_body,
			$script_accept_cookies,
			$section_id,
			$update_id );

		$query_result = $wpdb->query( $safe_sql );

		if ( $query_result !== false ) {
			$process_data_message = '<div class="updated settings-error notice is-dismissible below-h2"><p>' . esc_html__( 'The category has been successfully updated.', 'lightweight-cookie-notice') . '</p></div>';
		}

	} else {


		//Add

		global $wpdb;
		$table_name = $wpdb->prefix . $this->shared->get( 'slug' ) . "_category";
		$safe_sql   = $wpdb->prepare( "INSERT INTO $table_name SET 
                name = %s,
                description = %s,
                toggle = %d,
                default_status = %d,
                priority = %d,
                script_head = %s,
                script_body = %s,
                script_accept_cookies = %s,
                section_id = %d",
			$name,
			$description,
			$toggle,
			$default_status,
			$priority,
			$script_head,
			$script_body,
			$script_accept_cookies,
			$section_id
		);

		$query_result = $wpdb->query( $safe_sql );

		if ( $query_result !== false ) {
			$process_data_message = '<div class="updated settings-error notice is-dismissible below-h2"><p>' . esc_html__( 'The category has been successfully added.', 'lightweight-cookie-notice') . '</p></div>';
		}

	}

}

//delete a category
if ( isset( $_POST['delete_id'] ) ) {

	global $wpdb;
	$delete_id = intval( $_POST['delete_id'], 10 );

	//prevent deletion if the category is associated with a section
	if ( $this->shared->category_is_used_in_cookies( $delete_id ) ) {

		$process_data_message = '<div class="error settings-error notice is-dismissible below-h2"><p>' . esc_html__( "This category is associated with one or more cookies and can't be deleted.", 'lightweight-cookie-notice') . '</p></div>';

	} else {

		$table_name   = $wpdb->prefix . $this->shared->get( 'slug' ) . "_category";
		$safe_sql     = $wpdb->prepare( "DELETE FROM $table_name WHERE category_id = %d ", $delete_id );
		$query_result = $wpdb->query( $safe_sql );

		if ( $query_result !== false ) {
			$process_data_message = '<div class="updated settings-error notice is-dismissible below-h2"><p>' . esc_html__( 'The category has been successfully deleted.', 'lightweight-cookie-notice') . '</p></div>';
		}

	}

}

//get the category data
if ( isset( $_GET['edit_id'] ) ) {
	$edit_id = intval( $_GET['edit_id'], 10 );
	global $wpdb;
	$table_name   = $wpdb->prefix . $this->shared->get( 'slug' ) . "_category";
	$safe_sql     = $wpdb->prepare( "SELECT * FROM $table_name WHERE category_id = %d ", $edit_id );
	$category_obj = $wpdb->get_row( $safe_sql );
}

?>

<!-- output -->

<div class="wrap">

    <div id="daext-header-wrapper" class="daext-clearfix">

        <h2><?php esc_html_e( 'Lightweight Cookie Notice - Categories', 'lightweight-cookie-notice'); ?></h2>

        <form action="admin.php" method="get" id="daext-search-form">

            <input type="hidden" name="page" value="daextlwcn-categories">

            <p><?php esc_html_e( 'Perform your Search', 'lightweight-cookie-notice'); ?></p>

			<?php
			if ( isset( $_GET['s'] ) and mb_strlen( trim( $_GET['s'] ) ) > 0 ) {
				$search_string = sanitize_text_field( $_GET['s'] );
			} else {
				$search_string = '';
			}
			?>

            <input type="text" name="s"
                   value="<?php echo esc_attr( stripslashes( $search_string ) ); ?>" autocomplete="off" maxlength="255">
            <input type="submit" value="">

        </form>

    </div>

    <div id="daext-menu-wrapper">

		<?php if ( isset( $invalid_data_message ) ) {
			echo $invalid_data_message;
		} ?>
		<?php if ( isset( $process_data_message ) ) {
			echo $process_data_message;
		} ?>

        <!-- table -->

		<?php

		$filter = '';

		//create the query part used to filter the results when a search is performed
		if ( mb_strlen( trim( $filter ) ) === 0 and isset( $_GET['s'] ) and mb_strlen( trim( $_GET['s'] ) ) > 0 ) {
			$search_string = sanitize_text_field( $_GET['s'] );
			global $wpdb;
			$filter = $wpdb->prepare( 'WHERE (name LIKE %s OR description LIKE %s)',
				'%' . $search_string . '%',
				'%' . $search_string . '%' );
		}

		//retrieve the total number of categories
		global $wpdb;
		$table_name  = $wpdb->prefix . $this->shared->get( 'slug' ) . "_category";
		$total_items = $wpdb->get_var( "SELECT COUNT(*) FROM $table_name $filter" );

		//Initialize the pagination class
		require_once( $this->shared->get( 'dir' ) . '/admin/inc/class-daextlwcn-pagination.php' );
		$pag = new daextlwcn_pagination();
		$pag->set_total_items( $total_items );//Set the total number of items
		$pag->set_record_per_page( 10 ); //Set records per page
		$pag->set_target_page( "admin.php?page=" . $this->shared->get( 'slug' ) . "-categories" );//Set target page
		$pag->set_current_page();//set the current page number from $_GET

		?>

        <!-- Query the database -->
		<?php
		$query_limit = $pag->query_limit();
		$results     = $wpdb->get_results( "SELECT * FROM $table_name $filter ORDER BY category_id DESC $query_limit",
			ARRAY_A ); ?>

		<?php if ( count( $results ) > 0 ) : ?>

            <div class="daext-items-container">

                <!-- list of tables -->
                <table class="daext-items">
                    <thead>
                    <tr>
                        <th>
                            <div><?php esc_html_e( 'Category ID', 'lightweight-cookie-notice'); ?></div>
                            <div class="help-icon"
                                 title="<?php esc_attr_e( 'The ID of the category.', 'lightweight-cookie-notice'); ?>"></div>
                        </th>
                        <th>
                            <div><?php esc_html_e( 'Name', 'lightweight-cookie-notice'); ?></div>
                            <div class="help-icon"
                                 title="<?php esc_attr_e( 'The name of the category.', 'lightweight-cookie-notice'); ?>"></div>
                        </th>
                        <th>
                            <div><?php esc_html_e( 'Section', 'lightweight-cookie-notice'); ?></div>
                            <div class="help-icon"
                                 title="<?php esc_attr_e( 'The section where the category will be displayed.', 'lightweight-cookie-notice'); ?>"></div>
                        </th>
                        <th>
                            <div><?php esc_html_e( 'Acceptance', 'lightweight-cookie-notice'); ?></div>
                            <div class="help-icon"
                                 title="<?php esc_attr_e( 'The percentage of acceptance for this category.', 'lightweight-cookie-notice'); ?>"></div>
                        </th>
                        <th></th>
                    </tr>
                    </thead>
                    <tbody>

					<?php foreach ( $results as $result ) : ?>
                        <tr>
                            <td><?php echo intval( $result['category_id'], 10 ); ?></td>
                            <td><?php echo esc_html( stripslashes( $result['name'] ) ); ?></td>
                            <td><?php echo esc_html( stripslashes( $this->shared->get_section_name( $result['section_id'] ) ) ); ?></td>
                            <td><?php echo esc_html( $this->shared->get_category_acceptance( $result['category_id'] ) ); ?></td>
                            <td class="icons-container">
                                <a class="menu-icon edit"
                                   href="admin.php?page=<?php echo $this->shared->get( 'slug' ); ?>-categories&edit_id=<?php echo intval( $result['category_id'],
									   10 ); ?>"></a>
                                <form id="form-delete-<?php echo intval( $result['category_id'], 10 ); ?>" method="POST"
                                      action="admin.php?page=<?php echo $this->shared->get( 'slug' ); ?>-categories">
                                    <input type="hidden" value="<?php echo intval( $result['category_id'], 10 ); ?>"
                                           name="delete_id">
                                    <input class="menu-icon delete" type="submit" value="">
                                </form>
                            </td>
                        </tr>
					<?php endforeach; ?>

                    </tbody>

                </table>

            </div>

            <!-- Display the pagination -->
			<?php if ( $pag->total_items > 0 ) : ?>
                <div class="daext-tablenav daext-clearfix">
                    <div class="daext-tablenav-pages">
                        <span class="daext-displaying-num"><?php echo $pag->total_items; ?>
                            &nbsp<?php esc_html_e( 'items', 'lightweight-cookie-notice'); ?></span>
						<?php $pag->show(); ?>
                    </div>
                </div>
			<?php endif; ?>

		<?php else : ?>

			<?php

			if ( mb_strlen( trim( $filter ) ) > 0 ) {
				echo '<div class="error settings-error notice is-dismissible below-h2"><p>' . esc_html__( 'There are no results that match your filter.', 'lightweight-cookie-notice') . '</p></div>';
			}

			?>

		<?php endif; ?>

        <div>

            <form method="POST" action="admin.php?page=<?php echo $this->shared->get( 'slug' ); ?>-categories"
                  autocomplete="off">

                <input type="hidden" value="1" name="form_submitted">

				<?php if ( isset( $_GET['edit_id'] ) ) : ?>

                <!-- Edit a Category -->

                <div class="daext-form-container">

                    <h3 class="daext-form-title"><?php esc_html_e( 'Edit Category', 'lightweight-cookie-notice'); ?>&nbsp<?php echo $category_obj->category_id; ?></h3>

                    <table class="daext-form daext-form-table">

                        <input type="hidden" name="update_id"
                               value="<?php echo $category_obj->category_id; ?>"/>

                        <!-- Name -->
                        <tr valign="top">
                            <th><label for="title"><?php esc_html_e( 'Name', 'lightweight-cookie-notice'); ?></label></th>
                            <td>
                                <input value="<?php echo esc_attr( stripslashes( $category_obj->name ) ); ?>"
                                       type="text" id="name" maxlength="100" size="30" name="name"/>
                                <div class="help-icon"
                                     title="<?php esc_attr_e( 'The name of the category.', 'lightweight-cookie-notice'); ?>"></div>
                            </td>
                        </tr>

                        <!-- Description -->
                        <tr valign="top">
                            <th><label for="description"><?php esc_html_e( 'Description', 'lightweight-cookie-notice'); ?></label></th>
                            <td>
                                <textarea type="text" id="description" maxlength="100000"
                                          name="description"><?php echo esc_html( stripslashes( $category_obj->description ) ); ?></textarea>
                                <div class="help-icon"
                                     title="<?php esc_attr_e( 'The description of the category.', 'lightweight-cookie-notice'); ?>"></div>
                            </td>
                        </tr>

                        <!-- Section ID -->
                        <tr>
                            <th scope="row"><label for="tags"><?php esc_html_e( 'Section', 'lightweight-cookie-notice'); ?></label></th>
                            <td>
								<?php

								$html = '<select id="section-id" name="section_id" class="daext-display-none">';

								$html .= '<option value="0" ' . selected( $category_obj->section_id, 0,
										false ) . '>' . esc_html__( 'None', 'lightweight-cookie-notice') . '</option>';

								global $wpdb;
								$table_name = $wpdb->prefix . $this->shared->get( 'slug' ) . "_section";
								$sql        = "SELECT section_id, name FROM $table_name ORDER BY section_id DESC";
								$section_a  = $wpdb->get_results( $sql, ARRAY_A );

								foreach ( $section_a as $key => $section ) {
									$html .= '<option value="' . $section['section_id'] . '" ' . selected( $category_obj->section_id,
											$section['section_id'],
											false ) . '>' . esc_html( stripslashes( $section['name'] ) ) . '</option>';
								}

								$html .= '</select>';
								$html .= '<div class="help-icon" title="' . esc_attr__( 'The section where the category will be displayed.', 'lightweight-cookie-notice') . '"></div>';

								echo $html;

								?>
                            </td>
                        </tr>

                        <!-- Toggle -->
                        <tr class="top">
                            <th scope="row"><?php esc_html_e( 'Toggle', 'lightweight-cookie-notice'); ?></th>
                            <td>
                                <select id="toggle" name="toggle" class="daext-display-none">
                                    <option value="0" <?php selected( intval( $category_obj->toggle, 10 ),
										0 ); ?>><?php esc_html_e( 'Disabled', 'lightweight-cookie-notice'); ?></option>
                                    <option value="1" <?php selected( intval( $category_obj->toggle, 10 ),
										1 ); ?>><?php esc_html_e( 'Enabled', 'lightweight-cookie-notice'); ?></option>
                                </select>
                                <div class="help-icon"
                                     title='<?php esc_attr_e( 'This option determines if the toggle should be enabled.', 'lightweight-cookie-notice'); ?>'></div>
                            </td>
                        </tr>

                        <!-- Default Status -->
                        <tr class="top">
                            <th scope="row"><?php esc_html_e( 'State', 'lightweight-cookie-notice'); ?></th>
                            <td>
                                <select id="default-status" name="default_status" class="daext-display-none">
                                    <option value="0" <?php selected( intval( $category_obj->default_status, 10 ),
										0 ); ?>><?php esc_html_e( 'Disabled', 'lightweight-cookie-notice'); ?></option>
                                    <option value="1" <?php selected( intval( $category_obj->default_status, 10 ),
										1 ); ?>><?php esc_html_e( 'Enabled', 'lightweight-cookie-notice'); ?></option>
                                </select>
                                <div class="help-icon"
                                     title='<?php esc_attr_e( 'This option determines the initial state of the category.', 'lightweight-cookie-notice'); ?>'></div>
                            </td>
                        </tr>

                        <!-- Script Head -->
                        <tr valign="top">
                            <th><label for="script-head"><?php esc_html_e( 'HTML Head', 'lightweight-cookie-notice'); ?></label></th>
                            <td>
                                <textarea type="text" id="script-head" name="script_head"
                                          maxlength="100000"><?php echo esc_attr( stripslashes( $category_obj->script_head ) ); ?></textarea>
                                <div class="help-icon"
                                     title="<?php esc_attr_e( 'The HTML that will be added to the page HEAD section if the user has given consent.', 'lightweight-cookie-notice'); ?>"></div>
                            </td>
                        </tr>

                        <!-- Script Body -->
                        <tr valign="top">
                            <th><label for="script-body"><?php esc_html_e( 'HTML Body', 'lightweight-cookie-notice'); ?></label></th>
                            <td>
                                <textarea type="text" id="script-body" name="script_body"
                                          maxlength="100000"><?php echo esc_attr( stripslashes( $category_obj->script_body ) ); ?></textarea>
                                <div class="help-icon"
                                     title="<?php esc_attr_e( 'The HTML that will be added to the page BODY section if the user has given consent.', 'lightweight-cookie-notice'); ?>"></div>
                            </td>
                        </tr>

                        <!-- Priority -->
                        <tr valign="top">
                            <th><label for="priority"><?php esc_html_e( 'Priority', 'lightweight-cookie-notice'); ?></label></th>
                            <td>
                                <input value="<?php echo intval( $category_obj->priority, 10 ); ?>" type="text"
                                       id="priority" maxlength="3" name="priority">
                                <div class="help-icon"
                                     title="<?php esc_attr_e( 'The priority value determines the order used to display the sections.', 'lightweight-cookie-notice'); ?>"></div>
                            </td>
                        </tr>

                        <!-- Advanced Options ------------------------------------------------------------ -->
                        <tr class="group-trigger" data-trigger-target="advanced-options">
                            <th class="group-title"><?php esc_attr_e('Advanced', 'lightweight-cookie-notice'); ?></th>
                            <td>
                                <div class="expand-icon"></div>
                            </td>
                        </tr>

                        <!-- On Accept -->
                        <tr class="advanced-options" valign="top">
                            <th><label for="script-accept-cookies"><?php esc_html_e( 'Accept Cookies Script', 'lightweight-cookie-notice'); ?></label></th>
                            <td>
                                <textarea type="text" id="script-accept-cookies" name="script_accept_cookies"
                                          maxlength="100000"><?php echo esc_attr( stripslashes( $category_obj->script_accept_cookies ) ); ?></textarea>
                                <div class="help-icon"
                                     title="<?php esc_attr_e( 'This JavaScript code runs when the user clicks a button associated with an "Accept Cookies" action, and this category is enabled.', 'lightweight-cookie-notice'); ?>"></div>
                            </td>
                        </tr>

                    </table>

                    <!-- submit button -->
                    <div class="daext-form-action">
                        <input class="button" type="submit"
                               value="<?php esc_attr_e( 'Update Category', 'lightweight-cookie-notice'); ?>">
                        <input id="cancel" class="button" type="submit"
                               value="<?php esc_attr_e( 'Cancel', 'lightweight-cookie-notice'); ?>">
                    </div>

					<?php else : ?>

                    <!-- Create a Category -->

                    <div class="daext-form-container">

                        <div class="daext-form-title"><?php esc_html_e( 'Create New Category', 'lightweight-cookie-notice'); ?></div>

                        <table class="daext-form daext-form-table">

                            <!-- Name -->
                            <tr valign="top">
                                <th><label for="title"><?php esc_html_e( 'Name', 'lightweight-cookie-notice'); ?></label></th>
                                <td>
                                    <input type="text" id="name" maxlength="100" size="30" name="name"/>
                                    <div class="help-icon"
                                         title="<?php esc_attr_e( 'The name of the category.', 'lightweight-cookie-notice'); ?>"></div>
                                </td>
                            </tr>

                            <!-- Description -->
                            <tr valign="top">
                                <th><label for="description"><?php esc_html_e( 'Description', 'lightweight-cookie-notice'); ?></label>
                                </th>
                                <td>
                                    <textarea type="text" id="description" maxlength="100000"
                                              name="description"></textarea>
                                    <div class="help-icon"
                                         title="<?php esc_attr_e( 'The description of the category.', 'lightweight-cookie-notice'); ?>"></div>
                                </td>
                            </tr>

                            <!-- Section ID -->
                            <tr>
                                <th scope="row"><label for="tags"><?php esc_html_e( 'Section', 'lightweight-cookie-notice'); ?></label>
                                </th>
                                <td>
									<?php

									$html = '<select id="section-id" name="section_id" class="daext-display-none">';

									$html .= '<option value="0" ' . selected( intval( get_option( $this->shared->get( 'slug' ) . "_defaults_section_id" ) ),
											0, false ) . '>' . esc_html__( 'None', 'lightweight-cookie-notice') . '</option>';

									global $wpdb;
									$table_name = $wpdb->prefix . $this->shared->get( 'slug' ) . "_section";
									$sql        = "SELECT section_id, name FROM $table_name ORDER BY section_id DESC";
									$section_a  = $wpdb->get_results( $sql, ARRAY_A );

									foreach ( $section_a as $key => $section ) {
										$html .= '<option value="' . $section['section_id'] . '">' . esc_html( stripslashes( $section['name'] ) ) . '</option>';
									}

									$html .= '</select>';
									$html .= '<div class="help-icon" title="' . esc_attr__( 'The section where the category will be displayed.', 'lightweight-cookie-notice') . '"></div>';

									echo $html;

									?>
                                </td>
                            </tr>

                            <!-- Toggle -->
                            <tr class="top">
                                <th scope="row"><?php esc_html_e( 'Toggle', 'lightweight-cookie-notice'); ?></th>
                                <td>
                                    <select id="toggle" name="toggle" class="daext-display-none">
                                        <option value="0"><?php esc_html_e( 'Disabled', 'lightweight-cookie-notice'); ?></option>
                                        <option value="1" selected="selected"><?php esc_html_e( 'Enabled', 'lightweight-cookie-notice'); ?></option>
                                    </select>
                                    <div class="help-icon"
                                         title='<?php esc_attr_e( 'This option determines if the toggle should be enabled.', 'lightweight-cookie-notice'); ?>'></div>
                                </td>
                            </tr>

                            <!-- Default Status -->
                            <tr class="top">
                                <th scope="row"><?php esc_html_e( 'State', 'lightweight-cookie-notice'); ?></th>
                                <td>
                                    <select id="default-status" name="default_status" class="daext-display-none">
                                        <option value="0"><?php esc_html_e( 'Disabled', 'lightweight-cookie-notice'); ?></option>
                                        <option value="1" selected="selected"><?php esc_html_e( 'Enabled', 'lightweight-cookie-notice'); ?></option>
                                    </select>
                                    <div class="help-icon"
                                         title='<?php esc_attr_e( 'This option determines the initial state of the category.', 'lightweight-cookie-notice'); ?>'></div>
                                </td>
                            </tr>

                            <!-- Script Head -->
                            <tr valign="top">
                                <th><label for="script-head"><?php esc_html_e( 'HTML Head', 'lightweight-cookie-notice'); ?></label>
                                </th>
                                <td>
                                    <textarea type="text" id="script-head" name="script_head"
                                              maxlength="100000"></textarea>
                                    <div class="help-icon"
                                         title="<?php esc_attr_e( 'The HTML that will be added to the page HEAD section if the user has given consent.', 'lightweight-cookie-notice'); ?>"></div>
                                </td>
                            </tr>

                            <!-- Script Body -->
                            <tr valign="top">
                                <th><label for="script-body"><?php esc_html_e( 'HTML Body', 'lightweight-cookie-notice'); ?></label>
                                </th>
                                <td>
                                    <textarea type="text" id="script-body" name="script_body"
                                              maxlength="100000"></textarea>
                                    <div class="help-icon"
                                         title="<?php esc_attr_e( 'The HTML that will be added to the page BODY section if the user has given consent.', 'lightweight-cookie-notice'); ?>"></div>
                                </td>
                            </tr>

                            <!-- Priority -->
                            <tr valign="top">
                                <th><label for="priority"><?php esc_html_e( 'Priority', 'lightweight-cookie-notice'); ?></label></th>
                                <td>
                                    <input type="text" value="0" id="priority" maxlength="3" name="priority"></input>
                                    <div class="help-icon"
                                         title="<?php esc_attr_e( 'The priority value determines the order used to display the sections.', 'lightweight-cookie-notice'); ?>"></div>
                                </td>
                            </tr>

                            <!-- Advanced Options ------------------------------------------------------------ -->
                            <tr class="group-trigger" data-trigger-target="advanced-options">
                                <th class="group-title"><?php esc_attr_e('Advanced', 'lightweight-cookie-notice'); ?></th>
                                <td>
                                    <div class="expand-icon"></div>
                                </td>
                            </tr>

                            <!-- On Accept -->
                            <tr class="advanced-options" valign="top">
                                <th><label for="script-accept-cookies"><?php esc_html_e( 'Accept Cookies Script', 'lightweight-cookie-notice'); ?></label>
                                </th>
                                <td>
                                    <textarea type="text" id="script-accept-cookies" name="script_accept_cookies"
                                              maxlength="100000"></textarea>
                                    <div class="help-icon"
                                         title="<?php esc_attr_e( 'This JavaScript code runs when the user clicks a button associated with an "Accept Cookies" action, and this category is enabled.', 'lightweight-cookie-notice'); ?>"></div>
                                </td>
                            </tr>

                        </table>

                        <!-- submit button -->
                        <div class="daext-form-action">
                            <input class="button" type="submit"
                                   value="<?php esc_attr_e( 'Add Category', 'lightweight-cookie-notice'); ?>">
                        </div>

						<?php endif; ?>

                    </div>

            </form>

        </div>

    </div>

</div>