<?php

if ( ! current_user_can( get_option( $this->shared->get( 'slug' ) . '_capability_menu_cookies' ) ) ) {
	wp_die( esc_html__( 'You do not have sufficient permissions to access this page.', 'lightweight-cookie-notice') );
}

?>

<!-- process data -->

<?php

if ( isset( $_POST['form_submitted'] ) ) {

	//Sanitization -----------------------------------------------------------------------------------------------------
	$update_id   = isset( $_POST['update_id'] ) ? intval( $_POST['update_id'] ) : '';
	$provider    = sanitize_text_field( $_POST['provider'] );
	$domain      = sanitize_text_field( $_POST['domain'] );
	$name        = sanitize_text_field( $_POST['name'] );
	$purpose     = $this->shared->apply_custom_kses( $_POST['purpose'] );
	$expiration  = sanitize_text_field( $_POST['expiration'] );
	$type        = sanitize_text_field( $_POST['type'] );
	$sensitivity = sanitize_text_field( $_POST['sensitivity'] );
	$security    = sanitize_text_field( $_POST['security'] );
	$category_id = sanitize_text_field( $_POST['category_id'] );
	$priority    = intval( $_POST['priority'], 10 );

	//Validation -------------------------------------------------------------------------------------------------------

	$invalid_data_message = '';

	//validation on "name"
	if ( mb_strlen( trim( $name ) ) === 0 or mb_strlen( trim( $name ) ) > 255 ) {
		$invalid_data_message .= '<div class="error settings-error notice is-dismissible below-h2"><p>' . esc_html__( 'Please enter a valid value in the "Name" field.', 'lightweight-cookie-notice') . '</p></div>';
		$invalid_data         = true;
	}

	//validation on "expiration"
	if ( mb_strlen( trim( $expiration ) ) === 0 or mb_strlen( trim( $expiration ) ) > 255 ) {
		$invalid_data_message .= '<div class="error settings-error notice is-dismissible below-h2"><p>' . esc_html__( 'Please enter a valid value in the "Expiration" field.', 'lightweight-cookie-notice') . '</p></div>';
		$invalid_data         = true;
	}

	//validation on "purpose"
	if ( mb_strlen( trim( $purpose ) ) === 0 or mb_strlen( trim( $purpose ) ) > 100000 ) {
		$invalid_data_message .= '<div class="error settings-error notice is-dismissible below-h2"><p>' . esc_html__( 'Please enter a valid value in the "Purpose" field.', 'lightweight-cookie-notice') . '</p></div>';
		$invalid_data         = true;
	}

}

//Update or add the record in the database
if ( isset( $_POST['form_submitted'] ) and ! isset( $invalid_data ) ) {

	if ( isset( $update_id ) and ! empty( $update_id ) ) {

		//Update

		global $wpdb;
		$table_name = $wpdb->prefix . $this->shared->get( 'slug' ) . "_cookie";
		$safe_sql   = $wpdb->prepare( "UPDATE $table_name SET 
                provider = %s,
                domain = %s,
                name = %s,
                purpose = %s,
                expiration = %s,
                type = %s,
                sensitivity = %s,
                security = %s,
                category_id = %d,
                priority = %d
                WHERE cookie_id = %d",
			$provider,
			$domain,
			$name,
			$purpose,
			$expiration,
			$type,
			$sensitivity,
			$security,
			$category_id,
			$priority,
			$update_id
		);

		$query_result = $wpdb->query( $safe_sql );

		if ( $query_result !== false ) {
			$process_data_message = '<div class="updated settings-error notice is-dismissible below-h2"><p>' . esc_html__( 'The cookie has been successfully updated.', 'lightweight-cookie-notice') . '</p></div>';
		}

	} else {


		//Add

		global $wpdb;
		$table_name = $wpdb->prefix . $this->shared->get( 'slug' ) . "_cookie";
		$safe_sql   = $wpdb->prepare( "INSERT INTO $table_name SET 
                provider = %s,
                domain = %s,
                name = %s,
                purpose = %s,
                expiration = %s,
                type = %s,
                sensitivity = %s,
                security = %s,
                category_id = %d,
                priority = %d",
			$provider,
			$domain,
			$name,
			$purpose,
			$expiration,
			$type,
			$sensitivity,
			$security,
			$category_id,
			$priority
		);

		$query_result = $wpdb->query( $safe_sql );

		if ( $query_result !== false ) {
			$process_data_message = '<div class="updated settings-error notice is-dismissible below-h2"><p>' . esc_html__( 'The cookie has been successfully added.', 'lightweight-cookie-notice') . '</p></div>';
		}

	}

}

//delete a cookie
if ( isset( $_POST['delete_id'] ) ) {

	global $wpdb;
	$delete_id = intval( $_POST['delete_id'], 10 );

	$table_name   = $wpdb->prefix . $this->shared->get( 'slug' ) . "_cookie";
	$safe_sql     = $wpdb->prepare( "DELETE FROM $table_name WHERE cookie_id = %d ", $delete_id );
	$query_result = $wpdb->query( $safe_sql );

	if ( $query_result !== false ) {
		$process_data_message = '<div class="updated settings-error notice is-dismissible below-h2"><p>' . esc_html__( 'The cookie has been successfully deleted.', 'lightweight-cookie-notice') . '</p></div>';
	}

}

//clone the cookie
if ( isset( $_POST['clone_id'] ) ) {

	global $wpdb;
	$clone_id = intval( $_POST['clone_id'], 10 );

	//clone the cookie
	$table_name = $wpdb->prefix . $this->shared->get( 'slug' ) . "_cookie";
	$safe_sql   = $wpdb->prepare( "CREATE TEMPORARY TABLE daextlwcn_temporary_table SELECT * FROM $table_name WHERE cookie_id = %d",
		$clone_id );
	$wpdb->query( $safe_sql );
	$wpdb->query( "UPDATE daextlwcn_temporary_table SET cookie_id = NULL" );
	$wpdb->query( "INSERT INTO $table_name SELECT * FROM daextlwcn_temporary_table" );
	$wpdb->query( "DROP TEMPORARY TABLE IF EXISTS daextlwcn_temporary_table" );

}

//get the cookie data
if ( isset( $_GET['edit_id'] ) ) {
	$edit_id = intval( $_GET['edit_id'], 10 );
	global $wpdb;
	$table_name = $wpdb->prefix . $this->shared->get( 'slug' ) . "_cookie";
	$safe_sql   = $wpdb->prepare( "SELECT * FROM $table_name WHERE cookie_id = %d ", $edit_id );
	$cookie_obj = $wpdb->get_row( $safe_sql );
}

?>

<!-- output -->

<div class="wrap">

    <div id="daext-header-wrapper" class="daext-clearfix">

        <h2><?php esc_html_e( 'Lightweight Cookie Notice - Cookies', 'lightweight-cookie-notice'); ?></h2>

        <form action="admin.php" method="get" id="daext-search-form">

            <input type="hidden" name="page" value="daextlwcn-categories">

            <p><?php esc_html_e( 'Perform your Search', 'lightweight-cookie-notice'); ?></p>

			<?php
			if ( isset( $_GET['s'] ) and mb_strlen( trim( $_GET['s'] ) ) > 0 ) {
				$search_string = sanitize_text_field( $_GET['s'] );
			} else {
				$search_string = '';
			}
			?>

            <input type="text" name="s"
                   value="<?php echo esc_attr( stripslashes( $search_string ) ); ?>" autocomplete="off" maxlength="255">
            <input type="submit" value="">

        </form>

    </div>

    <div id="daext-menu-wrapper">

		<?php if ( isset( $invalid_data_message ) ) {
			echo $invalid_data_message;
		} ?>
		<?php if ( isset( $process_data_message ) ) {
			echo $process_data_message;
		} ?>

        <!-- table -->

		<?php

		$filter = '';

		//create the query part used to filter the results when a search is performed
		if ( mb_strlen( trim( $filter ) ) === 0 and isset( $_GET['s'] ) and mb_strlen( trim( $_GET['s'] ) ) > 0 ) {
			$search_string = sanitize_text_field( $_GET['s'] );
			global $wpdb;
			$filter = $wpdb->prepare( 'WHERE (name LIKE %s)',
				'%' . $search_string . '%' );
		}

		//retrieve the total number of categories
		global $wpdb;
		$table_name  = $wpdb->prefix . $this->shared->get( 'slug' ) . "_cookie";
		$total_items = $wpdb->get_var( "SELECT COUNT(*) FROM $table_name $filter" );

		//Initialize the pagination class
		require_once( $this->shared->get( 'dir' ) . '/admin/inc/class-daextlwcn-pagination.php' );
		$pag = new daextlwcn_pagination();
		$pag->set_total_items( $total_items );//Set the total number of items
		$pag->set_record_per_page( 10 ); //Set records per page
		$pag->set_target_page( "admin.php?page=" . $this->shared->get( 'slug' ) . "-cookies" );//Set target page
		$pag->set_current_page();//set the current page number from $_GET

		?>

        <!-- Query the database -->
		<?php
		$query_limit = $pag->query_limit();
		$results     = $wpdb->get_results( "SELECT * FROM $table_name $filter ORDER BY cookie_id DESC $query_limit",
			ARRAY_A ); ?>

		<?php if ( count( $results ) > 0 ) : ?>

            <div class="daext-items-container">

                <!-- cookie of tables -->
                <table class="daext-items">
                    <thead>
                    <tr>
                        <th>
                            <div><?php esc_html_e( 'Cookie ID', 'lightweight-cookie-notice'); ?></div>
                            <div class="help-icon"
                                 title="<?php esc_attr_e( 'The ID of the cookie.', 'lightweight-cookie-notice'); ?>"></div>
                        </th>
                        <th>
                            <div><?php esc_html_e( 'Cookie', 'lightweight-cookie-notice'); ?></div>
                            <div class="help-icon"
                                 title="<?php esc_attr_e( 'The name of the cookie.', 'lightweight-cookie-notice'); ?>"></div>
                        </th>
                        <th></th>
                    </tr>
                    </thead>
                    <tbody>

					<?php foreach ( $results as $result ) : ?>
                        <tr>
                            <td><?php echo intval( $result['cookie_id'], 10 ); ?></td>
                            <td><?php echo esc_html( stripslashes( $result['name'] ) ); ?></td>
                            <td class="icons-container">
                                <a class="menu-icon edit"
                                   href="admin.php?page=<?php echo $this->shared->get( 'slug' ); ?>-cookies&edit_id=<?php echo intval( $result['cookie_id'],
									   10 ); ?>"></a>
                                <form id="form-delete-<?php echo intval( $result['cookie_id'], 10 ); ?>" method="POST"
                                      action="admin.php?page=<?php echo $this->shared->get( 'slug' ); ?>-cookies">
                                    <input type="hidden" value="<?php echo intval( $result['cookie_id'], 10 ); ?>"
                                           name="delete_id">
                                    <input class="menu-icon delete" type="submit" value="">
                                </form>
                            </td>
                        </tr>
					<?php endforeach; ?>

                    </tbody>

                </table>

            </div>

            <!-- Display the pagination -->
			<?php if ( $pag->total_items > 0 ) : ?>
                <div class="daext-tablenav daext-clearfix">
                    <div class="daext-tablenav-pages">
                        <span class="daext-displaying-num"><?php echo $pag->total_items; ?>
                            &nbsp<?php esc_html_e( 'items', 'lightweight-cookie-notice'); ?></span>
						<?php $pag->show(); ?>
                    </div>
                </div>
			<?php endif; ?>

		<?php else : ?>

			<?php

			if ( mb_strlen( trim( $filter ) ) > 0 ) {
				echo '<div class="error settings-error notice is-dismissible below-h2"><p>' . esc_html__( 'There are no results that match your filter.', 'lightweight-cookie-notice') . '</p></div>';
			}

			?>

		<?php endif; ?>

        <div>

            <form method="POST" action="admin.php?page=<?php echo $this->shared->get( 'slug' ); ?>-cookies"
                  autocomplete="off">

                <input type="hidden" value="1" name="form_submitted">

				<?php if ( isset( $_GET['edit_id'] ) ) : ?>

                <!-- Edit a Cookie -->

                <div class="daext-form-container">

                    <h3 class="daext-form-title"><?php esc_html_e( 'Edit Cookie', 'lightweight-cookie-notice'); ?>&nbsp<?php echo intval( $cookie_obj->cookie_id, 10 ); ?></h3>

                    <table class="daext-form daext-form-table">

                        <input type="hidden" name="update_id"
                               value="<?php echo intval( $cookie_obj->cookie_id, 10 ); ?>"/>

                        <!-- Name -->
                        <tr valign="top">
                            <th><label for="title"><?php esc_html_e( 'Name', 'lightweight-cookie-notice'); ?></label></th>
                            <td>
                                <input value="<?php echo esc_attr( stripslashes( $cookie_obj->name ) ); ?>" type="text"
                                       id="name" maxlength="255" size="30" name="name"/>
                                <div class="help-icon"
                                     title="<?php esc_attr_e( 'The name of the cookie.', 'lightweight-cookie-notice'); ?>"></div>
                            </td>
                        </tr>

                        <!-- Expiration -->
                        <tr valign="top">
                            <th><label for="title"><?php esc_html_e( 'Expiration', 'lightweight-cookie-notice'); ?></label></th>
                            <td>
                                <input value="<?php echo esc_attr( stripslashes( $cookie_obj->expiration ) ); ?>"
                                       type="text" id="expiration" maxlength="255" size="30" name="expiration"/>
                                <div class="help-icon"
                                     title="<?php esc_attr_e( 'The expiration of the cookie.', 'lightweight-cookie-notice'); ?>"></div>
                            </td>
                        </tr>

                        <!-- Purpose -->
                        <tr valign="top">
                            <th><label for="purpose"><?php esc_html_e( 'Purpose', 'lightweight-cookie-notice'); ?></label></th>
                            <td>
                                <textarea type="text" id="purpose" maxlength="100000"
                                          name="purpose"><?php echo esc_html( stripslashes( $cookie_obj->purpose ) ); ?></textarea>
                                <div class="help-icon"
                                     title="<?php esc_attr_e( 'The purpose of the cookie.', 'lightweight-cookie-notice'); ?>"></div>
                            </td>
                        </tr>

                        <!-- Priority -->
                        <tr valign="top">
                            <th><label for="priority"><?php esc_html_e( 'Priority', 'lightweight-cookie-notice'); ?></label></th>
                            <td>
                                <input value="<?php echo intval( $cookie_obj->priority, 10 ); ?>" type="text"
                                       id="priority" maxlength="3" name="priority">
                                <div class="help-icon"
                                     title="<?php esc_attr_e( 'The priority value determines the order used to display the cookies.', 'lightweight-cookie-notice'); ?>"></div>
                            </td>
                        </tr>

                        <!-- Category -->
                        <tr>
                            <th scope="row"><label for="category"><?php esc_html_e( 'Category', 'lightweight-cookie-notice'); ?></label></th>
                            <td>
								<?php

								$html = '<select id="category-id" name="category_id" class="daext-display-none">';

								$html .= '<option value="0" selected="selected">' . esc_html__( 'None', 'lightweight-cookie-notice') . '</option>';

								global $wpdb;
								$table_name = $wpdb->prefix . $this->shared->get( 'slug' ) . "_category";
								$sql        = "SELECT category_id, name FROM $table_name ORDER BY category_id DESC";
								$category_a = $wpdb->get_results( $sql, ARRAY_A );

								foreach ( $category_a as $key => $category ) {
									$html .= '<option value="' . intval( $category['category_id'],
											10 ) . '" ' . selected( $cookie_obj->category_id,
											$category['category_id'],
											false ) . '>' . esc_html( stripslashes( $category['name'] ) ) . '</option>';
								}

								$html .= '</select>';
								$html .= '<div class="help-icon" title="' . esc_attr__( 'The category associated with the cookie.', 'lightweight-cookie-notice') . '"></div>';

								echo $html;

								?>
                            </td>
                        </tr>

                        <!-- Advanced Options ---------------------------------------------- -->
                        <tr class="group-trigger" data-trigger-target="advanced-options">
                            <th
                                    class="group-title"><?php esc_attr_e( 'Advanced', 'lightweight-cookie-notice'); ?></th>
                            <td>
                                <div class="expand-icon"></div>
                            </td>
                        </tr>

                        <!-- Provider -->
                        <tr valign="top" class="advanced-options">
                            <th><label for="title"><?php esc_html_e( 'Provider', 'lightweight-cookie-notice'); ?></label></th>
                            <td>
                                <input value="<?php echo esc_attr( stripslashes( $cookie_obj->provider ) ); ?>"
                                       type="text" id="provider" maxlength="255" size="30" name="provider"/>
                                <div class="help-icon"
                                     title="<?php esc_attr_e( 'The provider of the cookie.', 'lightweight-cookie-notice'); ?>"></div>
                            </td>
                        </tr>

                        <!-- Domain -->
                        <tr valign="top" class="advanced-options">
                            <th><label for="title"><?php esc_html_e( 'Domain', 'lightweight-cookie-notice'); ?></label></th>
                            <td>
                                <input value="<?php echo esc_attr( stripslashes( $cookie_obj->domain ) ); ?>"
                                       type="text" id="domain" maxlength="255" size="30" name="domain"/>
                                <div class="help-icon"
                                     title="<?php esc_attr_e( 'The provider of the cookie.', 'lightweight-cookie-notice'); ?>"></div>
                            </td>
                        </tr>

                        <!-- Type -->
                        <tr valign="top" class="advanced-options">
                            <th><label for="title"><?php esc_html_e( 'Type', 'lightweight-cookie-notice'); ?></label></th>
                            <td>
                                <input value="<?php echo esc_attr( stripslashes( $cookie_obj->type ) ); ?>" type="text"
                                       id="type" maxlength="255" size="30" name="type"/>
                                <div class="help-icon"
                                     title="<?php esc_attr_e( 'The type of the cookie.', 'lightweight-cookie-notice'); ?>"></div>
                            </td>
                        </tr>

                        <!-- Sensitivity -->
                        <tr valign="top" class="advanced-options">
                            <th><label for="title"><?php esc_html_e( 'Sensitivity', 'lightweight-cookie-notice'); ?></label></th>
                            <td>
                                <input value="<?php echo esc_attr( stripslashes( $cookie_obj->sensitivity ) ); ?>"
                                       type="text" id="sensitivity" maxlength="255" size="30" name="sensitivity"/>
                                <div class="help-icon"
                                     title="<?php esc_attr_e( 'The sensitivity of the cookie.', 'lightweight-cookie-notice'); ?>"></div>
                            </td>
                        </tr>

                        <!-- Security -->
                        <tr valign="top" class="advanced-options">
                            <th><label for="title"><?php esc_html_e( 'Security', 'lightweight-cookie-notice'); ?></label></th>
                            <td>
                                <input value="<?php echo esc_attr( stripslashes( $cookie_obj->security ) ); ?>"
                                       type="text" id="security" maxlength="255" size="30" name="security"/>
                                <div class="help-icon"
                                     title="<?php esc_attr_e( 'The security of the cookie.', 'lightweight-cookie-notice'); ?>"></div>
                            </td>
                        </tr>

                    </table>

                    <!-- submit button -->
                    <div class="daext-form-action">
                        <input class="button" type="submit"
                               value="<?php esc_attr_e( 'Update Cookie', 'lightweight-cookie-notice'); ?>">
                        <input id="cancel" class="button" type="submit"
                               value="<?php esc_attr_e( 'Cancel', 'lightweight-cookie-notice'); ?>">
                    </div>

					<?php else : ?>

                    <!-- Create a Cookie -->

                    <div class="daext-form-container">

                        <div class="daext-form-title"><?php esc_html_e( 'Create New Cookie', 'lightweight-cookie-notice'); ?></div>

                        <table class="daext-form daext-form-table">

                            <!-- Name -->
                            <tr valign="top">
                                <th><label for="title"><?php esc_html_e( 'Name', 'lightweight-cookie-notice'); ?></label></th>
                                <td>
                                    <input type="text" id="name" maxlength="255" size="30" name="name"/>
                                    <div class="help-icon"
                                         title="<?php esc_attr_e( 'The name of the cookie.', 'lightweight-cookie-notice'); ?>"></div>
                                </td>
                            </tr>

                            <!-- Expiration -->
                            <tr valign="top">
                                <th><label for="title"><?php esc_html_e( 'Expiration', 'lightweight-cookie-notice'); ?></label></th>
                                <td>
                                    <input type="text" id="expiration" maxlength="255" size="30" name="expiration"/>
                                    <div class="help-icon"
                                         title="<?php esc_attr_e( 'The expiration of the cookie.', 'lightweight-cookie-notice'); ?>"></div>
                                </td>
                            </tr>

                            <!-- Purpose -->
                            <tr valign="top">
                                <th><label for="purpose"><?php esc_html_e( 'Purpose', 'lightweight-cookie-notice'); ?></label></th>
                                <td>
                                    <textarea type="text" id="purpose" maxlength="100000" name="purpose"></textarea>
                                    <div class="help-icon"
                                         title="<?php esc_attr_e( 'The purpose of the cookie', 'lightweight-cookie-notice'); ?>"></div>
                                </td>
                            </tr>

                            <!-- Priority -->
                            <tr valign="top">
                                <th><label for="priority"><?php esc_html_e( 'Priority', 'lightweight-cookie-notice'); ?></label></th>
                                <td>
                                    <input type="text" value="0" id="priority" maxlength="3" name="priority"></input>
                                    <div class="help-icon"
                                         title="<?php esc_attr_e( 'The priority value determines the order used to display the cookies.', 'lightweight-cookie-notice'); ?>"></div>
                                </td>
                            </tr>

                            <!-- Category -->
                            <tr>
                                <th scope="row"><label for="category"><?php esc_html_e( 'Category', 'lightweight-cookie-notice'); ?></label></th>
                                <td>
									<?php

									$html = '<select id="category-id" name="category_id" class="daext-display-none">';

									$html .= '<option value="0" selected="selected">' . esc_html__( 'None', 'lightweight-cookie-notice') . '</option>';

									global $wpdb;
									$table_name = $wpdb->prefix . $this->shared->get( 'slug' ) . "_category";
									$sql        = "SELECT category_id, name FROM $table_name ORDER BY category_id DESC";
									$category_a = $wpdb->get_results( $sql, ARRAY_A );

									foreach ( $category_a as $key => $category ) {
										$html .= '<option value="' . $category['category_id'] . '">' . esc_html( stripslashes( $category['name'] ) ) . '</option>';
									}

									$html .= '</select>';
									$html .= '<div class="help-icon" title="' . esc_attr__( 'The category associated with the cookie.', 'lightweight-cookie-notice') . '"></div>';

									echo $html;

									?>
                                </td>
                            </tr>

                            <!-- Advanced Options ---------------------------------------------- -->
                            <tr class="group-trigger" data-trigger-target="advanced-options">
                                <th
                                        class="group-title"><?php esc_attr_e( 'Advanced', 'lightweight-cookie-notice'); ?></th>
                                <td>
                                    <div class="expand-icon"></div>
                                </td>
                            </tr>

                            <!-- Provider -->
                            <tr valign="top" class="advanced-options">
                                <th><label for="title"><?php esc_html_e( 'Provider', 'lightweight-cookie-notice'); ?></label></th>
                                <td>
                                    <input type="text" id="provider" maxlength="255" size="30" name="provider"/>
                                    <div class="help-icon"
                                         title="<?php esc_attr_e( 'The provider of the cookie.', 'lightweight-cookie-notice'); ?>"></div>
                                </td>
                            </tr>

                            <!-- Domain -->
                            <tr valign="top" class="advanced-options">
                                <th><label for="title"><?php esc_html_e( 'Domain', 'lightweight-cookie-notice'); ?></label></th>
                                <td>
                                    <input type="text" id="domain" maxlength="255" size="30" name="domain"/>
                                    <div class="help-icon"
                                         title="<?php esc_attr_e( 'The domain of the cookie.', 'lightweight-cookie-notice'); ?>"></div>
                                </td>
                            </tr>

                            <!-- Type -->
                            <tr valign="top" class="advanced-options">
                                <th><label for="title"><?php esc_html_e( 'Type', 'lightweight-cookie-notice'); ?></label></th>
                                <td>
                                    <input type="text" id="provider" maxlength="255" size="30" name="type"/>
                                    <div class="help-icon"
                                         title="<?php esc_attr_e( 'The type of the cookie.', 'lightweight-cookie-notice'); ?>"></div>
                                </td>
                            </tr>

                            <!-- Sensitivity -->
                            <tr valign="top" class="advanced-options">
                                <th><label for="title"><?php esc_html_e( 'Sensitivity', 'lightweight-cookie-notice'); ?></label></th>
                                <td>
                                    <input type="text" id="sensitivity" maxlength="255" size="30" name="sensitivity"/>
                                    <div class="help-icon"
                                         title="<?php esc_attr_e( 'The sensitivity of the cookie.', 'lightweight-cookie-notice'); ?>"></div>
                                </td>
                            </tr>

                            <!-- Security -->
                            <tr valign="top" class="advanced-options">
                                <th><label for="title"><?php esc_html_e( 'Security', 'lightweight-cookie-notice'); ?></label></th>
                                <td>
                                    <input type="text" id="security" maxlength="255" size="30" name="security"/>
                                    <div class="help-icon"
                                         title="<?php esc_attr_e( 'The security of the cookie.', 'lightweight-cookie-notice'); ?>"></div>
                                </td>
                            </tr>

                        </table>

                        <!-- submit button -->
                        <div class="daext-form-action">
                            <input class="button" type="submit"
                                   value="<?php esc_attr_e( 'Add Cookie', 'lightweight-cookie-notice'); ?>">
                        </div>

						<?php endif; ?>

                    </div>

            </form>

        </div>

    </div>

</div>