<?php

if ( ! current_user_can( get_option( $this->shared->get( 'slug' ) . '_capability_menu_import' ) ) ) {
	wp_die( esc_html__( 'You do not have sufficient permissions to access this page.', 'lightweight-cookie-notice') );
}

?>

<!-- output -->

<div class="wrap">

    <h2><?php esc_html_e( 'Lightweight Cookie Notice - Import', 'lightweight-cookie-notice'); ?></h2>

    <div id="daext-menu-wrapper">

		<?php

		//process the xml file upload
		if ( isset( $_FILES['file_to_upload'] ) and
		     isset( $_FILES['file_to_upload']['name'] ) and
		     preg_match( '/^.+\.xml$/', $_FILES['file_to_upload']['name'], $matches ) === 1
		) {

			if ( file_exists( $_FILES['file_to_upload']['tmp_name'] ) ) {

				global $wpdb;

				$counter_section             = 0;
				$counter_category            = 0;
				$counter_category_acceptance = 0;
				$counter_cookie              = 0;
				$category_id_hash_table      = array();

				//Delete the records of all the database tables of the plugin
				$this->shared->reset_plugin_database_tables();

				//Set the default values of the options
				$this->shared->reset_plugin_options();

				//read xml file
				$xml = simplexml_load_file( $_FILES['file_to_upload']['tmp_name'] );

				//Import Sections --------------------------------------------------------------------------------------
				$section_a = $xml->section;

				$num = count( $section_a );

				for ( $i = 0; $i < $num; $i ++ ) {

					//convert object to array
					$single_section_a = get_object_vars( $section_a[ $i ] );

					//replace objects with empty strings to prevent notices on the next insert() method
					$single_section_a = $this->shared->replace_objects_with_empty_strings( $single_section_a );

					/*
					 * Save the section_id key for later use and remove the section_id key from the
					 * main array.
					 */
					$current_section_id = $single_section_a['section_id'];
					unset( $single_section_a['section_id'] );

					$table_name = $wpdb->prefix . $this->shared->get( 'slug' ) . "_section";
					$wpdb->insert(
						$table_name,
						$single_section_a
					);
					$inserted_section_id = $wpdb->insert_id;
					$counter_section     += $wpdb->rows_affected;

					//Add the old and new section_id in the hash table
					$section_id_hash_table[ $current_section_id ] = $inserted_section_id;

				}

				//Import Categories ------------------------------------------------------------------------------------
				$category_a = $xml->category;

				$num = count( $category_a );

				for ( $i = 0; $i < $num; $i ++ ) {

					//convert object to array
					$single_category_a = get_object_vars( $category_a[ $i ] );

					//replace objects with empty strings to prevent notices on the next insert() method
					$single_category_a = $this->shared->replace_objects_with_empty_strings( $single_category_a );

					/*
                     * Save the category_id key for later use and remove the category_id key from the
                     * main array.
                     */
					$current_category_id = $single_category_a['category_id'];
					unset( $single_category_a['category_id'] );

					//replace the section_id value with zero or the one available in $section_id_hash_table
					if ( intval( $single_category_a['section_id'], 10 ) === 0 ) {
						$single_category_a['section_id'] = 0;
					} else {
						$single_category_a['section_id'] = $section_id_hash_table[ $single_category_a['section_id'] ];
					}

					$table_name = $wpdb->prefix . $this->shared->get( 'slug' ) . "_category";
					$wpdb->insert(
						$table_name,
						$single_category_a
					);
					$inserted_category_id = $wpdb->insert_id;
					$counter_category     += $wpdb->rows_affected;

					//Add the old and new category_id in the hash table
					$category_id_hash_table[ $current_category_id ] = $inserted_category_id;

				}

				//Import Category Acceptance ---------------------------------------------------------------------------
				$category_acceptance_a = $xml->category_acceptance;

				$num = count( $category_acceptance_a );

				for ( $i = 0; $i < $num; $i ++ ) {

					//convert object to array
					$single_category_acceptance_a = get_object_vars( $category_acceptance_a[ $i ] );

					//replace objects with empty strings to prevent notices on the next insert() method
					$single_category_acceptance_a = $this->shared->replace_objects_with_empty_strings( $single_category_acceptance_a );

					//remove the id key
					unset( $single_category_acceptance_a['category_acceptance_id'] );

					//replace the category_id value with zero or the one available in $category_id_hash_table
					if ( intval( $single_category_acceptance_a['category_id'], 10 ) === 0 ) {
						$single_category_acceptance_a['category_id'] = 0;
					} else {
						$single_category_acceptance_a['category_id'] = $category_id_hash_table[ $single_category_acceptance_a['category_id'] ];
					}

					$table_name = $wpdb->prefix . $this->shared->get( 'slug' ) . "_category_acceptance";
					$wpdb->insert(
						$table_name,
						$single_category_acceptance_a
					);
					$counter_category_acceptance += $wpdb->rows_affected;

				}

				//Import Cookies ---------------------------------------------------------------------------------------
				$cookie_a = $xml->cookie;

				$num = count( $cookie_a );

				for ( $i = 0; $i < $num; $i ++ ) {

					//convert object to array
					$single_cookie_a = get_object_vars( $cookie_a[ $i ] );

					//replace objects with empty strings to prevent notices on the next insert() method
					$single_cookie_a = $this->shared->replace_objects_with_empty_strings( $single_cookie_a );

					//remove the id key
					unset( $single_cookie_a['cookie_id'] );

					//replace the category_id value with zero or the one available in $category_id_hash_table
					if ( intval( $single_cookie_a['category_id'], 10 ) === 0 ) {
						$single_cookie_a['category_id'] = 0;
					} else {
						$single_cookie_a['category_id'] = $category_id_hash_table[ $single_cookie_a['category_id'] ];
					}

					$table_name = $wpdb->prefix . $this->shared->get( 'slug' ) . "_cookie";
					$wpdb->insert(
						$table_name,
						$single_cookie_a
					);
					$counter_cookie += $wpdb->rows_affected;

				}

				$success_message = '<div class="updated settings-error notice is-dismissible below-h2">';
				$success_message .= '<p>' . esc_html__( 'The following elements have been added:', 'lightweight-cookie-notice') . ' ';
				$success_message .= $counter_section . ' ' . esc_html__( 'sections', 'lightweight-cookie-notice') . ', ';
				$success_message .= $counter_category . ' ' . esc_html__( 'categories', 'lightweight-cookie-notice') . ', ';
				$success_message .= $counter_category_acceptance . ' ' . esc_html__( 'category acceptance', 'lightweight-cookie-notice') . ', ';
				$success_message .= $counter_cookie . ' ' . esc_html__( 'cookies', 'lightweight-cookie-notice') . '.</p></div>';

				echo $success_message;

			}

		}

		?>

        <p><?php esc_html_e( 'Import the plugin data stored in your XML file by clicking the Upload file and import button.', 'lightweight-cookie-notice'); ?></p>
        <form enctype="multipart/form-data" id="import-upload-form" method="post" class="wp-upload-form" action="">
            <p>
                <label for="upload"><?php esc_html_e( 'Choose a file from your computer:', 'lightweight-cookie-notice'); ?></label>
                <input type="file" id="upload" name="file_to_upload">
            </p>
            <p class="submit"><input type="submit" name="submit" id="submit" class="button button-primary"
                                     value="<?php esc_attr_e( 'Upload file and import', 'lightweight-cookie-notice'); ?>"></p>
        </form>
        <p>
            <strong><?php esc_html_e( 'IMPORTANT: This menu should only be used to import the XML files generated with the "Export" menu.', 'lightweight-cookie-notice'); ?></strong></p>

    </div>

</div>