const {registerBlockType} = wp.blocks;
const {InspectorControls} = wp.blockEditor;
const {Component} = wp.element;
const {__} = wp.i18n;

import GenericReactSelect from '../../components/GenericReactSelect';
import FeatherIcon from '../../components/FeatherIcon';

class BlockEdit extends Component {

  constructor(props) {

    super(...arguments);
    this.props = props;

    //Initialize the attributes
    if (typeof this.props.attributes.categoryId === 'undefined') {
      this.props.setAttributes({categoryId: '0'});
    }

  }

  render() {

    const categoryIdData = {
      action: 'daextlwcn_get_category_data',
      attributeName: 'categoryId',
      title: __('Category', 'lightweight-cookie-notice'),
    };

    return [
      <div className="daextlwcn-block-image" key="daextlwcn-block-image">{__(
          'Cookies', 'daextlwcn')}</div>,
      <InspectorControls key="inspector">
        <GenericReactSelect data={categoryIdData}
                            attributes={this.props.attributes}
                            setAttributes={this.props.setAttributes}/>
      </InspectorControls>,
    ];

  }

}

/**
 * Register the Gutenberg block
 */
registerBlockType('daextlwcn/cookies', {
  title: __('Cookies', 'lightweight-cookie-notice'),
  icon: FeatherIcon,
  category: 'widgets',
  keywords: [
    __('cookie', 'lightweight-cookie-notice'),
    __('cookies', 'lightweight-cookie-notice'),
    __('lightweight', 'lightweight-cookie-notice'),
  ],
  attributes: {
    categoryId: {
      type: 'string',
    },
  },

  /**
   * The edit function describes the structure of your block in the context of the editor.
   * This represents what the editor will render when the block is used.
   *
   * The "edit" property must be a valid function.
   *
   * @link https://wordpress.org/gutenberg/handbook/block-api/block-edit-save/
   */
  edit: BlockEdit,

  /**
   * The save function defines the way in which the different attributes should be combined
   * into the final markup, which is then serialized by Gutenberg into post_content.
   *
   * The "save" property must be specified and must be a valid function.
   *
   * @link https://wordpress.org/gutenberg/handbook/block-api/block-edit-save/
   */
  save: function() {

    /**
     * This is a dynamic block and the rendering is performed with PHP:
     *
     * https://wordpress.org/gutenberg/handbook/blocks/creating-dynamic-blocks/
     */
    return null;

  },

});
