<?php

//Prevent direct access to this file
if ( ! defined( 'WPINC' ) ) {
	die();
}

/**
 * Enqueue the Gutenberg block assets for the backend.
 *
 * 'wp-blocks': includes block type registration and related functions.
 * 'wp-element': includes the WordPress Element abstraction for describing the structure of your blocks.
 */
function daextlwcn_editor_assets() {

	$shared = daextlwcn_Shared::get_instance();

	//Styles -----------------------------------------------------------------------------------------------------------

	//Block
	wp_enqueue_style(
		'daextlwcn-editor-css',
		plugins_url( 'dist/editor.css', dirname( __FILE__ ) ),
		array( 'wp-edit-blocks' )//Dependency to include the CSS after it.
	);

	//Scripts ----------------------------------------------------------------------------------------------------------

	//Block
	wp_enqueue_script(
		'daextlwcn-editor-js', // Handle.
		plugins_url( '/dist/blocks.build.js', dirname( __FILE__ ) ), //We register the block here.
		array( 'wp-blocks', 'wp-element' ), // Dependencies.
		false,
		true //Enqueue the script in the footer.
	);

	/*
	 * Add the translations associated with this script in the JED/json format.
	 *
	 * Reference: https://make.wordpress.org/core/2018/11/09/new-javascript-i18n-support-in-wordpress/
	 *
	 * Argument 1: Handler
	 * Argument 2: Domain
	 * Argument 3: Location where the JED/json file is located.
	 *
	 * Note that:
	 *
	 * - The JED/json file should be named [domain]-[locale]-[handle].json to be actually detected by WordPress.
	 * - The JED/json file is generated with https://github.com/mikeedwards/po2json from the .po file
	 */
	wp_set_script_translations( 'daextlwcn-editor-js', 'lightweight-cookie-notice', $shared->get( 'dir' ) . 'blocks/lang' );

}

add_action( 'enqueue_block_editor_assets', 'daextlwcn_editor_assets' );

/**
 * Enqueue the Gutenberg block assets for both frontend and backend.
 */
function daextlwcn_style_assets() {

	//Not used with this block.
	return;

	//Styles -----------------------------------------------------------------------------------------------------------
	wp_enqueue_style(
		'daextlwcn-style-css',
		plugins_url( 'dist/style.css', dirname( __FILE__ ) ),
		array( 'wp-blocks' )//Dependency to include the CSS after it
	);

}

add_action( 'enqueue_block_assets', 'daextlwcn_style_assets' );

/**
 * Dynamic Block Server Component
 *
 * For more info:
 *
 * https://wordpress.org/gutenberg/handbook/blocks/creating-dynamic-blocks/
 */
function daextlwcn_cookies_render( $attributes ) {

	$public = daextlwcn_Public::get_instance();

	return $public->print_cookie_table_html(
		[
			'category-id' => $attributes['categoryId'],
		]
	);

}

register_block_type( 'daextlwcn/cookies', array(
	'render_callback' => 'daextlwcn_cookies_render',
) );

/**
 * Dynamic Block Server Component
 *
 * For more info:
 *
 * https://wordpress.org/gutenberg/handbook/blocks/creating-dynamic-blocks/
 */
function daextlwcn_delete_cookies_render() {

	$public = daextlwcn_Public::get_instance();

	return $public->print_delete_cookies_button_html();

}

register_block_type( 'daextlwcn/delete-cookies', array(
	'render_callback' => 'daextlwcn_delete_cookies_render',
) );