<?php

/*
 * This class should be used to include ajax actions.
 */

class Daextlwcn_Ajax {

	protected static $instance = null;
	private $shared = null;

	private function __construct() {

		//assign an instance of the plugin info
		$this->shared = Daextlwcn_Shared::get_instance();

		//ajax requests for logged-in and not logged-in users
		add_action( 'wp_ajax_daextlwcn_geolocate_user', array( $this, 'daextlwcn_geolocate_user' ) );
		add_action( 'wp_ajax_nopriv_daextlwcn_geolocate_user', array( $this, 'daextlwcn_geolocate_user' ) );
		add_action( 'wp_ajax_nopriv_daextlwcn_save_category_acceptance',
			array( $this, 'daextlwcn_save_category_acceptance' ) );
		add_action( 'wp_ajax_daextlwcn_save_category_acceptance',
			array( $this, 'daextlwcn_save_category_acceptance' ) );

		//AJAX requests for logged-in users
		add_action( 'wp_ajax_daextlwcn_get_category_data', array( $this, 'daextlwcn_get_category_data' ) );


	}

	/*
	 * Return an istance of this class.
	 */
	public static function get_instance() {

		if ( null == self::$instance ) {
			self::$instance = new self;
		}

		return self::$instance;

	}

	/**
	 * Geolocate the user by using a database stored in the web server of the website.
	 *
	 * The following geolocation databases are currently supported:
	 *
	 * - MaxMind GeoLite2
	 */
	public function daextlwcn_geolocate_user() {

		//Check the referer
		if ( ! check_ajax_referer( 'daextlwcn', 'security', false ) ) {
			echo "Invalid AJAX Request";
			die();
		}

		$ip_address = $this->shared->get_ip_address();

		switch ( intval( get_option( $this->shared->get( 'slug' ) . '_geolocation_service' ), 10 ) ) {

			//MaxMind GeoLite2
			case 1:

				if ( $this->shared->is_valid_locale_maxmind_geolite2( $ip_address ) ) {
					$result = true;
				} else {
					$result = false;
				}

				break;

			//Default
			default:
				$result = true;
				break;

		}

		//Generate the json output from the tab array
		echo $result ? '1' : '0';

		die();

	}

	/**
	 * Save the acceptance statistic for all the cookie categories.
	 */
	public function daextlwcn_save_category_acceptance() {

		//Check the referer
		if ( ! check_ajax_referer( 'daextlwcn', 'security', false ) ) {
			echo "Invalid AJAX Request";
			die();
		}

		//Save the category acceptance of all the categories
		$category_cookies = json_decode( stripslashes( $_POST['category_cookies'] ) );
		foreach ( $category_cookies as $key => $category_cookie ) {

			global $wpdb;
			$table_name = $wpdb->prefix . $this->shared->get( 'slug' ) . "_category_acceptance";
			$safe_sql   = $wpdb->prepare( "INSERT INTO $table_name SET 
                category_id = %d,
                state = %d",
				intval( $category_cookie->categoryId, 10 ),
				intval( $category_cookie->status, 10 )
			);

			$query_result = $wpdb->query( $safe_sql );
			$result       = $query_result !== false ? 1 : 0;

		}

		//Generate the response and terminate the script
		echo $result;
		die();

	}

	/**
	 * Method used in the GenericReactSelect component of the "Cookies" Gutenberg blocks.
	 *
	 * A JSON string that includes name and ID of all the categories is returned.
	 */
	function daextlwcn_get_category_data() {

		//check the referer
		if ( ! check_ajax_referer( 'daextlwcn', 'security', false ) ) {
			echo "Invalid AJAX Request";
			die();
		}

		global $wpdb;
		$table_name = $wpdb->prefix . $this->shared->get( 'slug' ) . "_category";
		$sql        = "SELECT category_id, name FROM $table_name ORDER BY category_id DESC";
		$category_a = $wpdb->get_results( $sql, ARRAY_A );

		//Change the indexes to meet the requirements of the GenericReactSelect component
		foreach ( $category_a as $key => $category ) {
			$category_a[ $key ]['value'] = $category['category_id'];
			$category_a[ $key ]['label'] = stripslashes( $category['name'] );
			unset( $category_a[ $key ]['category_id'] );
			unset( $category_a[ $key ]['name'] );
		}

		//Set the default value at the beginning of the array
		array_unshift( $category_a,
			[
				'value' => '0',
				'label' => __( 'All', 'lightweight-cookie-notice')
			]
		);

		//Generate the response and terminate the script
		echo json_encode( $category_a );
		die();

	}

}